package org.amse.gk.grapheditor.algorithms;

import org.amse.gk.grapheditor.model.IGraph;

/**
 * Interface designed for working with {@link IAlgorithm}, providing
 * such basic function like its creation and access to some characteristics.  
 *
 */
public interface IAlgorithmCreator {
	
	/** 
	 * Creates new algorithm with a given graph 
	 * @param g   a graph we want to run algorithm with
	 * @return    a new algorithm according to our algorithm creator  
	 */
	IAlgorithm newAlgorithm(IGraph g);
	
	/**
	 * @return if we can run the algorithm with the given graph or not
	 */
	boolean isAlgorithmEnabled(IGraph graph);
	
	/** 
	 * @return a name of the algorithm, that can be run with our creator
	 */
	String getName(); 
}
