package org.amse.gk.grapheditor.algorithms;

/**
 * Interface designed for using with {@link IAlgorithm}, to support its
 * step-type work.  
 *
 * @see IAlgorithm
 */

public interface IStep {
	
	/** 
	 * Run the current step, modifying the states of graph elements
	 */
	void run();
	
	/** 
	 * Function allows to do iteration process with steps, executing 
	 * the according algorithm. 
	 * 
	 * @return the next step in step-type algorithm sequence
	 */
	IStep nextStep();
	
	/**
	 * Allows to know what type the step is, what action can fire it. 
	 * 
	 * @return the step type from {@link StepType} enumeration
	 */
	StepType getStepType();
		

	/**
	 * @return the text tip (maintenance) for the step, occurs before
	 * step running
	 *  
	 */
	String getBeforeStepDescription();
	
	/**
	 * @return the text tip (maintenance) for the step, occurs after
	 * step running
	 *  
	 */
	String getAfterStepDescription();
	

}
