package org.amse.gk.grapheditor.gui;

import javax.swing.*;

import java.awt.BorderLayout;
import java.awt.event.ActionEvent;
import java.awt.event.WindowEvent;

import org.amse.gk.grapheditor.gui.view.*;
import org.amse.gk.grapheditor.model.*;


@SuppressWarnings("serial")
public class MainFrame extends JFrame {

	private View myView; 
	
	private JToolBar myToolBar;	
	private JMenuBar myMenuBar;
	
	private Action myExitAction;
	
	public MainFrame(IGraph graph, Settings settings) {
		super("GraphEditor");		
		setDefaultCloseOperation(EXIT_ON_CLOSE);		
		setDefaultLookAndFeelDecorated(false);
		getContentPane().setLayout(new BorderLayout());		
		
		myView = new View(graph, this);		
		getContentPane().add(myView, BorderLayout.CENTER);
		
		myToolBar = createToolBar(settings);		
		getContentPane().add(myToolBar, BorderLayout.NORTH);
		myToolBar.setFloatable(false);
		
		myMenuBar = createMenuBar();
		setJMenuBar(myMenuBar);		
		
		setSize(settings.getWidth(), settings.getHeight());
		setLocation(settings.getX(), settings.getY());
		
		myView.setDirectory(settings.getDirectory());
		
		setVisible(true);		
	}	
	
	private JToolBar createToolBar(Settings settings) {
		JToolBar toolbar = new JToolBar();	
		
		ButtonGroup bg = new ButtonGroup();		
		for (Action state : myView.states()) {			
			JToggleButton button = new JToggleButton(state);
			button.setText(null);
			bg.add(button);			
			toolbar.add(button);
			if (state.getValue(Action.NAME).equals(settings.getState())) {
				myView.getGraphicPanel().setActiveState(state);		
				button.doClick();
			}
		}		
		toolbar.addSeparator();
		JButton b = new JButton(myView.new ApplyDefaultLayoutAction());	
		toolbar.add(b);		
		return toolbar;
	}
	
	private JMenuBar createMenuBar() {
		JMenuBar menuBar = new JMenuBar();
		
		JMenu fileMenu = new JMenu("File");
		JMenuItem newi = new JMenuItem(myView.getNewAction()); 
		JMenuItem open = new JMenuItem(myView.getOpenAction());
		JMenuItem save = new JMenuItem(myView.getSaveAction());	
		JMenuItem saveAs = new JMenuItem(myView.new SaveAsAction());
		myExitAction = myView.new ExitAction();
		JMenuItem exit = new JMenuItem(myView.new ExitAction());
		fileMenu.add(newi);
		fileMenu.add(open);
		fileMenu.addSeparator();
		fileMenu.add(save);
		fileMenu.add(saveAs);
		fileMenu.addSeparator();
		fileMenu.add(exit);
		
		JMenu algorithmsMenu = new JMenu("Algorithms");
		for (Action a : myView.algorithms()) {
			JMenuItem item = new JMenuItem(a);
			algorithmsMenu.add(item);
		}
		
		JMenu helpMenu = new JMenu("Help");
		JMenuItem about = new JMenuItem(myView.new AboutAction());
		helpMenu.add(about);
		
		menuBar.add(fileMenu);
		menuBar.add(algorithmsMenu);
		menuBar.add(helpMenu);
		return menuBar; 
	}	
	
	@Override
	protected void processWindowEvent(WindowEvent e) {		
		if (e.getID() == WindowEvent.WINDOW_CLOSING) {
			myExitAction.actionPerformed(new ActionEvent(this, 0, null));
	    } else {
	    	super.processWindowEvent(e);
	    }
	}


}
