package org.amse.gk.grapheditor.gui.view;

import javax.swing.*;
import java.awt.*;

import org.amse.gk.grapheditor.model.*;

public class GraphicPanel extends JPanel {

	private static final long serialVersionUID = 1L;
	
	private View myView;
	
	private IGraph myGraph;	
	
	private int myRadius = 5;
	
	private boolean myIsModified = true; 
	
	public GraphicPanel(IGraph graph, View view){
		super();
		myGraph = graph;
		myView = view;
		setBackground(Color.WHITE);		
		setVisible(true);
	}
	
	private void drawVertex(Graphics g, IVertex vertex, Color color) {
		g.setColor(color);
		g.fillOval(
			vertex.getX() - myRadius,
			vertex.getY() - myRadius,
			2 * myRadius + 1,
			2 * myRadius + 1);			
	}
	
	private void drawEdge(Graphics g, IEdge edge, Color color) {
		g.setColor(color);
		IVertex from = edge.getVertexFrom();
		IVertex to = edge.getVertexTo();
		int x1 = from.getX(), x2 = to.getX(), y1 = from.getY(), y2 = to.getY();
		
		double l = Math.sqrt((x2 - x1) * (x2 - x1) + (y2 - y1) * (y2 - y1));
		double sina = Math.sqrt(2)/2., cosa = Math.sqrt(2)/2.;
		double sinb = (y2 - y1) / l, cosb = (x2 - x1) / l;
		
		double cosg = cosa * cosb - sina * sinb;
		double sing = cosa * sinb + cosb * sina;
		int x = x2 - (int)((myRadius + 1) * cosb);
		int y = y2 - (int)((myRadius + 1) * sinb);
		int arrowX1 = x - (int)((myRadius + 2) * cosg);
		int arrowY1 = y - (int)((myRadius + 2) * sing);
		int arrowX2 = x - (int)((myRadius + 2) * sing);
		int arrowY2 = y + (int)((myRadius + 2) * cosg);		
		
		g.drawLine(x1, y1, x2, y2);
		g.drawLine(arrowX1, arrowY1, x, y);
		g.drawLine(arrowX2, arrowY2, x, y);		
		g.drawLine(arrowX1, arrowY1, arrowX2, arrowY2);
	}

	public void paintComponent(Graphics g){
		super.paintComponent(g);
		
		// Paint edges
		for (IEdge edge : myGraph.edges()) {			
			drawEdge(g, edge, myView.getActiveState().getColor(edge));
		}
		
		myView.getActiveState().drawFakeElements(g);

		// Paint vertices
		for (IVertex vertex : myGraph.vertices()) {
			drawVertex(g, vertex, myView.getActiveState().getColor(vertex));
		}		
	}
	
	public IVertex getVertex(int x, int y) {
		for (IVertex v : myGraph.vertices()) {
			if ((v.getX() - x)*(v.getX() - x) + (v.getY() - y)*(v.getY() - y) <= myRadius * myRadius){
				return v;
			}
		}
		return null;
	}
	
	public IEdge getEdge(int x, int y) {		
		for (IEdge e : myGraph.edges()) {
			double a = Math.sqrt((e.getVertexFrom().getX() - x)*(e.getVertexFrom().getX() - x) + 
					(e.getVertexFrom().getY() - y)*(e.getVertexFrom().getY() - y));
			double b = Math.sqrt((e.getVertexTo().getX() - x)*(e.getVertexTo().getX() - x) + 
					(e.getVertexTo().getY() - y)*(e.getVertexTo().getY() - y));
			double c = Math.sqrt((e.getVertexTo().getX() - e.getVertexFrom().getX())*(e.getVertexTo().getX() - e.getVertexFrom().getX()) + 
					(e.getVertexTo().getY() - e.getVertexFrom().getY())*(e.getVertexTo().getY() - e.getVertexFrom().getY()));
			double p = (a + b + c) / 2;
			double s = Math.sqrt(p * (p - a) * (p - b) * (p - c));
			double h = s / (2 * c); 
			if (h < 0.5 && a < c && b < c) {
				return e;
			}
		}
		return null;
	}		

	
	public IGraph getGraph() {
		return myGraph;
	}
	
	public void setGraph(IGraph g) {
		myGraph = g;		
	}
	
	public int getRadius() {
		return myRadius;
	}
	
	public boolean isModified() {
		if (myGraph.vertices().isEmpty()) 
			return false;
		return myIsModified;
	}
	
	public void setModified(boolean b) {
		myIsModified = b;
	}
	
	public void setActiveState(Action a) {
		myView.setActiveState(a);
	}
	
	public void updateAll() {
		repaint();
		setModified(true);
		myView.updateAll();
	}
	
}

