package org.amse.gk.grapheditor.gui.view;

import java.awt.Color;
import java.awt.Graphics;

import javax.swing.Action;
import javax.swing.event.MouseInputListener;

import org.amse.gk.grapheditor.model.IElement;

/**
 * Interface describes a mode using in {@link IView} to draw graph
 * according to action applied in this moment.
 * 
 * Implementations: {@link states.AddEdgeState}, {@link states.AddVertexState},
 * {@link states.SelectState}, {@link states.DeleteState}, {@link states.AlgorithmState}
 *
 */

public interface IViewState extends Action, MouseInputListener {
	
	/**
	 * Allow to draw elements that haven't existed yet, or some other
	 * ancillary things.
	 *  
	 * @param g Graphics
	 */
	void drawFakeElements(Graphics g);
	
	/**
	 * Provides the correct drawing of elements of the graph 
	 * @param e  graph element (vertex or edge)
	 * @return   color of the element, according to its state 
	 */
	Color getColor(IElement e);
}
