package org.amse.gk.grapheditor.gui.view.states;

import java.awt.Color;
import java.awt.Graphics;
import java.awt.event.MouseEvent;

import org.amse.gk.grapheditor.gui.view.GraphicPanel;
import org.amse.gk.grapheditor.model.*;

@SuppressWarnings("serial")
public class AddEdgeState extends StateAdaptor {
    private IVertex myActiveVertexFrom;
    private IVertex myActiveVertexTo;
    private boolean myDrawFakeEdge = false;
    private int myFakeX;
    private int myFakeY;
	
	public AddEdgeState(GraphicPanel graphicPanel, String iconName) {
		super(graphicPanel, "AddEdge", iconName);		
	}	

	@Override
	public void mouseDragged(MouseEvent e) {
		if (myActiveVertexFrom != null) {
			myFakeX = e.getX();
			myFakeY = e.getY();
			myDrawFakeEdge = true;
			IVertex vertex = getGraphicPanel().getVertex(myFakeX, myFakeY);
			if (vertex != myActiveVertexTo) {
				unselectElement(myActiveVertexTo);
				myActiveVertexTo = null;
				if (getGraphicPanel().getGraph().canAddEdge(myActiveVertexFrom, vertex)) {
					myActiveVertexTo = vertex;
					selectElement(myActiveVertexTo);
				}
			}
			if (myActiveVertexTo != null) {
				myFakeX = myActiveVertexTo.getX();
				myFakeY = myActiveVertexTo.getY();
			}
			getGraphicPanel().repaint();
		}
	}
	
	@Override
	public void drawFakeElements(Graphics g) {
		if (myDrawFakeEdge) {
			g.setColor(Color.BLACK);
			g.drawLine(myActiveVertexFrom.getX(), myActiveVertexFrom.getY(), myFakeX, myFakeY);
		}
	}
	
	@Override
	public void mouseReleased(MouseEvent e) {
		if (myActiveVertexFrom != null && myActiveVertexTo != null) {
			getGraphicPanel().getGraph().addEdge(myActiveVertexFrom, myActiveVertexTo);
			getGraphicPanel().updateAll();
		} else {
			getGraphicPanel().repaint();
		}
		myActiveVertexFrom = null;
		myActiveVertexTo = null;
		myDrawFakeEdge = false;
		unselectAllElements();		
	}
	
	@Override
	public void mouseMoved(MouseEvent e) {
		IVertex vertex = getGraphicPanel().getVertex(e.getX(), e.getY());
		if (vertex != myActiveVertexFrom) {
			unselectElement(myActiveVertexFrom);
			myActiveVertexFrom = vertex;
			selectElement(myActiveVertexFrom);
			getGraphicPanel().repaint();
		}
	}
	
	@Override
	public boolean isEnabled() {
		return !(getGraphicPanel().getGraph().vertices().size() <= 1);			
	}
	
	@Override
	public String getDescription() {		
		return "Add edge";
	}
	
	

}
