package org.amse.gk.grapheditor.gui.view.states;

import java.awt.event.MouseEvent;

import org.amse.gk.grapheditor.gui.view.GraphicPanel;
import org.amse.gk.grapheditor.model.IEdge;
import org.amse.gk.grapheditor.model.IVertex;

@SuppressWarnings("serial")
public class DeleteState extends StateAdaptor {

	private IVertex myActiveVertex;
	private IEdge myActiveEdge;
	
	public DeleteState(GraphicPanel graphicPanel, String iconName) {
		super(graphicPanel, "Delete", iconName);
	}	
	
	@Override
	public void mousePressed(MouseEvent e) {
		if (myActiveVertex != null) {
			getGraphicPanel().getGraph().removeVertex(myActiveVertex);
			getGraphicPanel().updateAll();
		} else if (myActiveEdge != null) {
			getGraphicPanel().getGraph().removeEdge(myActiveEdge);
			getGraphicPanel().updateAll();
		} else {
			getGraphicPanel().repaint();
		}
		unselectAllElements();
		
	}		
		
	@Override
	public void mouseMoved(MouseEvent e) {				
		IVertex vertex;
		IEdge edge;
		unselectAllElements();
		myActiveEdge = null;
		myActiveVertex = null;
		if ((vertex = getGraphicPanel().getVertex(e.getX(), e.getY())) != null){
			selectElement(vertex);		
			myActiveVertex = vertex;
		} else if ((edge = getGraphicPanel().getEdge(e.getX(), e.getY())) != null) {
			selectElement(edge);		
			myActiveEdge = edge;
		}
		getGraphicPanel().repaint();		
	}


	@Override
	public boolean isEnabled() {
		return !getGraphicPanel().getGraph().vertices().isEmpty();		
	}
	
	@Override
	public String getDescription() {		
		return "Delete vertex or edge";
	}


}
