package org.amse.gk.grapheditor.gui.view.states;

import java.awt.event.MouseEvent;

import org.amse.gk.grapheditor.gui.view.IViewState;
import org.amse.gk.grapheditor.gui.view.GraphicPanel;
import org.amse.gk.grapheditor.model.IVertex;

@SuppressWarnings("serial")
public class SelectState extends StateAdaptor implements IViewState {

	private IVertex myActiveVertex;
	
	public SelectState(GraphicPanel graphicPanel, String iconName) {
		super(graphicPanel, "Select", iconName);
	}	

	
	@Override
	public void mousePressed(MouseEvent e) {
		IVertex v;		
		myActiveVertex = null;
		if ((v = getGraphicPanel().getVertex(e.getX(), e.getY())) != null){
			unselectAllElements();
			myActiveVertex = v;
			selectElement(myActiveVertex);
			getGraphicPanel().repaint();
		}
	}
		
	@Override
	public void mouseDragged(MouseEvent e) {		
		if (myActiveVertex != null){	
			int x = e.getX(), y = e.getY();
			if (y < 0) {
				myActiveVertex.move(myActiveVertex.getX(), 0);
			} else if (y > getGraphicPanel().getHeight()) {
				myActiveVertex.move(myActiveVertex.getX(), getGraphicPanel().getHeight());
			} else {
				myActiveVertex.move(myActiveVertex.getX(), y);
			}
			if (x < 0) {
				myActiveVertex.move(0, myActiveVertex.getY());				
			} else if (x > getGraphicPanel().getWidth()) {				
				myActiveVertex.move(getGraphicPanel().getWidth(), myActiveVertex.getY());	
			} else {
				myActiveVertex.move(x, myActiveVertex.getY());
			}
			getGraphicPanel().updateAll();
		} 
	}
	
	@Override
	public void mouseMoved(MouseEvent e) {				
		IVertex vertex;		
		unselectAllElements();		
		if ((vertex = getGraphicPanel().getVertex(e.getX(), e.getY())) != null){
				selectElement(vertex);				
		}
		getGraphicPanel().repaint();		
	}

	@Override
	public boolean isEnabled() {
		return !getGraphicPanel().getGraph().vertices().isEmpty();	
	}

	@Override
	public String getDescription() {		
		return "Select vertex and move it";
	}
	
}