package org.amse.gk.grapheditor.gui.view.states;

import java.awt.Color;
import java.awt.Graphics;
import java.awt.event.ActionEvent;
import java.awt.event.MouseEvent;
import java.net.URL;
import java.util.HashSet;
import java.util.Set;


import javax.swing.*;

import org.amse.gk.grapheditor.GraphEditor;
import org.amse.gk.grapheditor.gui.view.*;
import org.amse.gk.grapheditor.model.*;

@SuppressWarnings("serial")
public abstract class StateAdaptor extends AbstractAction implements IViewState {
	private GraphicPanel myGraphicPanel;
	
	private Set<IElement> mySelectedElements = new HashSet<IElement>();	

	
	public StateAdaptor(GraphicPanel graphicPanel, String stateName, String iconName) {
		URL u = GraphEditor.class.getResource("utils/icons/" + iconName);
		if (u != null) {
			putValue(SMALL_ICON, new ImageIcon(u));
		}
		putValue(NAME, stateName);
		putValue(SHORT_DESCRIPTION, getDescription());
		myGraphicPanel = graphicPanel;
	}	
	
	protected void selectElement(IElement element) {
		if (element != null) {
			mySelectedElements.add(element);
		}
	}

	protected void unselectElement(IElement element) {
		mySelectedElements.remove(element);
	}

	protected void unselectAllElements() {
		mySelectedElements.clear();
	}
	
	public abstract String getDescription();
	
	public void drawFakeElements(Graphics g) {
	}

	public void actionPerformed(ActionEvent e) {
		myGraphicPanel.setActiveState(this);
	}
	
	protected GraphicPanel getGraphicPanel() {
		return myGraphicPanel;
	}

	public Color getColor(IElement e) {		
		if (e instanceof IVertex) {
			if (mySelectedElements.contains(e)) {
				return Color.CYAN;
			} 
			return Color.BLUE;			
		} else {
			if (mySelectedElements.contains(e)) {
				return Color.MAGENTA;			
			}
			return Color.GRAY;
		}
	}
	
	public void mouseClicked(MouseEvent e) {
	}

	public void mousePressed(MouseEvent e) {
	}

	public void mouseReleased(MouseEvent e) {
	}

	public void mouseEntered(MouseEvent e) {
	}	

	public void mouseExited(MouseEvent e) {
	}

	public void mouseDragged(MouseEvent e) {
	}

	public void mouseMoved(MouseEvent e) {
	}
}
