package org.amse.gk.grapheditor.io;

import java.io.File;
import java.io.IOException;
import java.util.HashMap;
import java.util.Map;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.parsers.ParserConfigurationException;

import org.amse.gk.grapheditor.model.IGraph;
import org.amse.gk.grapheditor.model.IVertex;

import org.w3c.dom.Document;
import org.w3c.dom.NamedNodeMap;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;
import org.xml.sax.SAXException;

public class GraphReader {
	private File myFile; 
	private Map<String, IVertex> myVertices;
	
	public GraphReader(File f) {
		myFile = f;
		myVertices = new HashMap<String, IVertex>();
	}

	private void buildGraph(IGraph graph, Node node) {
		if (node.getNodeType() == Node.ELEMENT_NODE) {
			final String nodeName = node.getNodeName();
			if (nodeName.equals("vertex")) {
				NamedNodeMap nnm = node.getAttributes();
				IVertex v = graph.addVertex(Integer.parseInt(nnm.item(1).getNodeValue()), Integer.parseInt(nnm.item(2).getNodeValue()));
				myVertices.put(nnm.item(0).getNodeValue().toString(), v);
			} else if (nodeName.equals("edge")) {
				NamedNodeMap nnm = node.getAttributes();
				graph.addEdge(myVertices.get(nnm.item(0).getNodeValue().toString()),
						myVertices.get(nnm.item(1).getNodeValue().toString()));
			}
		}
	}
	
	public void readGraph (IGraph graph) throws ReadGraphException {
		Document document = null;
		try {
			DocumentBuilder builder = DocumentBuilderFactory.newInstance().newDocumentBuilder();
			document = builder.parse(myFile);
		} catch (ParserConfigurationException e) {
			throw new ReadGraphException("Wrong format"); 
		} catch (SAXException e) {
			throw new ReadGraphException("Wrong format");
		} catch (IOException e) {
			throw new ReadGraphException("Can't read file");
		}
		if (document != null) {
			Node root = document.getDocumentElement();
			NodeList children = root.getChildNodes();
			final int childNumber = children.getLength();
			for (int i = 0; i < childNumber; ++i) {
				buildGraph(graph, children.item(i));
			}
		}
	}
	
}
