package org.amse.gk.grapheditor.io;

import java.io.File;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.parsers.ParserConfigurationException;

import javax.xml.transform.*;
import javax.xml.transform.dom.DOMSource;
import javax.xml.transform.stream.StreamResult;

import org.amse.gk.grapheditor.model.*;

import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.Node;

public class GraphWriter {
	private Document myDocument; 
	
	public GraphWriter(IGraph g) {
		DocumentBuilder builder = null;
		try {
			builder = DocumentBuilderFactory.newInstance().newDocumentBuilder();
		} catch (ParserConfigurationException e) {			
			//e.printStackTrace();
		}		
		Document document = builder.newDocument();
		Node root = document.createElement("graph");
		for (IVertex v : g.vertices()) {
			Element e = document.createElement("vertex");
			root.appendChild(e);
			
			e.setAttribute("name", v.getName());
			e.setAttribute("x", (new Integer(v.getX())).toString());
			e.setAttribute("y", (new Integer(v.getY())).toString());						
		}
		for (IEdge edge : g.edges()) {
			Element e = document.createElement("edge");
			root.appendChild(e);			
			
			e.setAttribute("from", edge.getVertexFrom().getName());
			e.setAttribute("to", edge.getVertexTo().getName());						
		}
		document.appendChild(root);
		myDocument = document;
	}
	
	public void writeGraph(File f) {
		try {
            Source source = new DOMSource(myDocument);    
            
            Result result = new StreamResult(f);
            
            TransformerFactory tf = TransformerFactory.newInstance();
            tf.setAttribute("indent-number", new Integer(2));
    
            Transformer t = tf.newTransformer();
            t.setOutputProperty(OutputKeys.INDENT, "yes");              
            t.transform(source, result);
        } catch (TransformerConfigurationException e) {
        } catch (TransformerException e) {
        }
	
	}
	
}
