package org.amse.gk.grapheditor.model;

import java.util.List;

/**
 * An interface describes a graph with vertices and directed edges, contained 
 * a structure without any data.
 * Implementations: AbstractGraph
 * 
 * @see AbstractGraph
 */

public interface IGraph {
	/**
	 * Adds new vertex to the graph.
	 */
	public IVertex addVertex(int x, int y);
	/**
	 * Removes a given vertex with all incident edges from the graph
	 */
	public void removeVertex(IVertex v);
	
	/**
	 * Returns an unmodifiable list of graph vertices 
	 */
	public List<IVertex> vertices();	

	/**
	 * Adds new edge to the graph.	
	 */
	public IEdge addEdge(IVertex from, IVertex to);
	
	/**
	 * Verifies if it is possible to add a new edge with given
	 * starting and terminal vertices.
	 * 
	 * @return   true if it is possible or false otherwise	 
	 */
	public boolean canAddEdge(IVertex from, IVertex to);
	/**
	 * Removes a given edge from the graph
	 */
	public void removeEdge(IEdge e);
	
	/**
	 * Returns an unmodifiable list of graph edges
	 */
	public List<IEdge> edges();

	/**
	 * Function applies default layout to the graph. Default layout 
	 * places vertices by circle, according to their order.
	 */
	public void applyDefaultLayout(int cx, int cy, int r);	
}

