package org.amse.gk.grapheditor.model.impl;

import org.amse.gk.grapheditor.model.IVertex;

/**
 * Class AbstractVertex is a basic implementation for {@link IVertex} interface.
 * It provides all optional {@link IVertex} operations.  
 *
 * @see IVertex
 */

class AbstractVertex implements IVertex{
	
	/**
	 * A vertex name
	 */
	private final String myName;
	
	/**
	 * An X-coordinate of the vertex 
	 */
	private int myX;
	
	/**
	 * An Y-coordinate of the vertex 
	 */
	private int myY;

	
	/**
	 * Constructs a vertex with given coordinates and name
	 * 
	 * @param name Name of the vertex
	 * @param x    The X-coordinate of the vertex
	 * @param y    The Y-coordinate of the vertex 
	 */	
	public AbstractVertex(String name, int x, int y){
		myName = name;
		myX = x;
		myY = y;
	}
	
	/**
	 * @return the X-coordinate of the vertex
	 */
	public int getX() {			
		return myX;
	}

	/**
	 * @return the Y-coordinate of the vertex
	 */
	public int getY() {		
		return myY;
	}

	/**
	 * Moves the vertex to a new position with given coordinates
	 * 
	 * @param x A new X-coordinate of the vertex
	 * @param y A new Y-coordinate of the vertex
	 */
	public void move(int x, int y) {
		myX = x;
		myY = y;
	}	

	@Override
	public String toString() {
		return myName;
	}

	/**
	 * @return the neme of the vertex 
	 */
	public String getName() {		
		return myName;
	}
}
