package org.amse.gk.grapheditor.tests;

import org.amse.gk.grapheditor.model.IEdge;
import org.amse.gk.grapheditor.model.IGraph;
import org.amse.gk.grapheditor.model.IVertex;
import org.amse.gk.grapheditor.model.impl.GraphFactory;

import junit.framework.TestCase;

public class ModelTest extends TestCase {
	public void test0(){
		IGraph g = GraphFactory.createGraph();
		assertTrue(g.toString().equals("0"));		
	}
	
	public void test1() {
		IGraph g = GraphFactory.createGraph();
		g.addVertex(20, 30);
		assertTrue(g.toString().equals("1\nVertex0 20 30"));
	}
	
	public void test2() {
		IGraph g = GraphFactory.createGraph();
		
		for (int i = 0; i < 10; i++){
			g.addVertex(i*10, i*5);
		}
		
		assertTrue(g.toString().equals("10\nVertex0 0 0\nVertex1 10 5\nVertex2 20 10\nVertex3 30 15\n" +
				"Vertex4 40 20\nVertex5 50 25\nVertex6 60 30\nVertex7 70 35\nVertex8 80 40\nVertex9 90 45"));
	}
	
	public void test3() {
		IGraph g = GraphFactory.createGraph();
		IVertex v[] = new IVertex[3]; 
		for (int i = 0; i < 3; i++){
			v[i] = g.addVertex(i*10, i*5);
		}
		g.addEdge(v[1], v[2]);		
		
		assertTrue(g.toString().equals("3\nVertex0 0 0\nVertex1 10 5\nVertex2 20 10\nEdge: Vertex1 -> Vertex2"));
	}
	
	public void test4() {
		IGraph g = GraphFactory.createGraph();
		IVertex v[] = new IVertex[4];
		
		for (int i = 0; i < 4; i++){
			v[i] = g.addVertex(i*10, i*5);
		}
		
		g.addEdge(v[0], v[1]);
		g.addEdge(v[0], v[2]);
		g.addEdge(v[0], v[3]);
		g.addEdge(v[1], v[0]);
		g.addEdge(v[2], v[3]);
		
		assertTrue(g.toString().equals("4\nVertex0 0 0\nVertex1 10 5\nVertex2 20 10\nVertex3 30 15\nEdge: Vertex0 -> Vertex1\nEdge: Vertex0 -> Vertex2\nEdge: Vertex0 -> Vertex3\nEdge: Vertex1 -> Vertex0\nEdge: Vertex2 -> Vertex3"));
	}
	
	public void test5() {
		IGraph g = GraphFactory.createGraph();
		g.addVertex(20, 30);
		g.removeVertex(g.vertices().get(0));
		assertTrue(g.toString().equals("0"));
	}
	
	public void test6() {
		IGraph g = GraphFactory.createGraph();
		IVertex v[] = new IVertex[10];
		
		for (int i = 0; i < 10; i++){
			v[i] = g.addVertex(i*10, i*5); 
		}
		g.removeVertex(v[1]);
		g.removeVertex(v[3]);
		g.removeVertex(v[0]);
		g.removeVertex(v[9]);		
		
		assertTrue(g.toString().equals("6\nVertex2 20 10\nVertex4 40 20\nVertex5 50 25\nVertex6 60 30\nVertex7 70 35\nVertex8 80 40"));
	}
	
	public void test7() {
		IGraph g = GraphFactory.createGraph();
		IVertex v[] = new IVertex[4];
		
		for (int i = 0; i < 4; i++){
			v[i] = g.addVertex(i*10, i*5);
		}
		g.addEdge(v[0], v[1]);
		g.addEdge(v[0], v[2]);
		g.addEdge(v[0], v[3]);
		g.addEdge(v[1], v[0]);
		g.addEdge(v[2], v[3]);
		g.removeVertex(v[0]);
		
		assertTrue(g.toString().equals("3\nVertex1 10 5\nVertex2 20 10\nVertex3 30 15\nEdge: Vertex2 -> Vertex3"));
	}
	
	public void test8() {
		IGraph g = GraphFactory.createGraph();
		
		IVertex[] vertices = new IVertex[5];
		for (int i = 0; i < 5; i++){
			vertices[i] = g.addVertex(i * 10, i * 5);
		}
		IEdge[] edges = new IEdge[5];
		edges[0] = g.addEdge(vertices[0], vertices[1]);
		edges[1] = g.addEdge(vertices[0], vertices[2]);
		edges[2] = g.addEdge(vertices[1], vertices[2]);
		edges[3] = g.addEdge(vertices[0], vertices[3]);
		edges[4] = g.addEdge(vertices[0], vertices[4]);
	
		g.removeEdge(edges[0]);
		g.removeEdge(edges[2]);
		g.removeEdge(edges[4]);		
		
		assertTrue(g.toString().equals("5\nVertex0 0 0\nVertex1 10 5\nVertex2 20 10\nVertex3 30 15\nVertex4 40 20\nEdge: Vertex0 -> Vertex2\nEdge: Vertex0 -> Vertex3"));
	}
	
	public void test9() {
		IGraph g = GraphFactory.createGraph();
		
		IVertex[] vertices = new IVertex[5];
		for (int i = 0; i < 5; i++){
			vertices[i] = g.addVertex(i * 10, i * 5);
		}
		g.applyDefaultLayout(100, 100, 5);
		assertTrue(g.toString().equals("5\nVertex0 100 95\nVertex1 104 99\nVertex2 102 104\nVertex3 98 104\nVertex4 96 99"));
	}
	
	public void test10() {
		IGraph g = GraphFactory.createGraph();
		
		IVertex[] vertices = new IVertex[5];
		for (int i = 0; i < 5; i++){
			vertices[i] = g.addVertex(i * 10, i * 5);
		}
		IEdge[] edges = new IEdge[5];
		edges[0] = g.addEdge(vertices[0], vertices[1]);
		edges[1] = g.addEdge(vertices[3], vertices[2]);
		edges[2] = g.addEdge(vertices[1], vertices[2]);
		edges[3] = g.addEdge(vertices[0], vertices[3]);
		edges[4] = g.addEdge(vertices[0], vertices[4]);
	
		assertTrue(!g.canAddEdge(vertices[3], vertices[2]));
		assertTrue(!g.canAddEdge(vertices[0], vertices[4]));
		assertTrue(g.canAddEdge(vertices[3], vertices[0]));	
		assertTrue(!g.canAddEdge(vertices[4], vertices[4]));
	}
	
	public void test11() {
		IGraph g = GraphFactory.createGraph();
		
		g.addVertex(10, 5);
		
		g.applyDefaultLayout(100, 100, 5);
		assertTrue(g.toString().equals("1\nVertex0 100 100"));
	}
}
